import os
import pandas as pd

def load_dataset(name):
    # Define the path to the datasets
    data_dir = os.path.join(os.path.dirname(__file__), 'data')
    dataset_path = os.path.join(data_dir, f'{name}.csv')
    
    # Check if the dataset exists
    if not os.path.isfile(dataset_path):
        raise ValueError(f"Dataset {name} does not exist.")
    
    # Load and return the dataset as a DataFrame
    return pd.read_csv(dataset_path)



from setuptools import setup, find_packages

setup(
    name='febedatasets',
    version='0.5',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'pandas',
    ],
    package_data={
        '': ['data/*.csv'],
    },
    author='Isaiah Chiraira',
    author_email='itchiraira@gmail.com',
    description='A package to load different datasets as dataframes',
    url='https://github.com/Tech-Gui/febe1004Datasets',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    license='MIT',  
)
